@@ -34,46 +34,7 @@ impl From<crate::W<SPI_TBR_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Field `vtb` reader - The Value of the Transmit Bits"]
-pub struct VTB_R(crate::FieldReader<u32, u32>);
-impl VTB_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u32) -> Self {
-        VTB_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for VTB_R {
-    type Target = crate::FieldReader<u32, u32>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `vtb` writer - The Value of the Transmit Bits"]
-pub struct VTB_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> VTB_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
-        self.w
-    }
-}
-impl R {
-    #[doc = "Bits 0:31 - The Value of the Transmit Bits"]
-    #[inline(always)]
-    pub fn vtb(&self) -> VTB_R {
-        VTB_R::new((self.bits & 0xffff_ffff) as u32)
-    }
-}
 impl W {
-    #[doc = "Bits 0:31 - The Value of the Transmit Bits"]
-    #[inline(always)]
-    pub fn vtb(&mut self) -> VTB_W {
-        VTB_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
@@ -81,7 +42,7 @@ impl W {
         self
     }
 }
-#[doc = "SPI TX Bit Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_tbr](index.html) module"]
+#[doc = "SPI TX Bit Register\n\nVTB \\[31:0\\]: The Value of the Transmit Bits\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_tbr](index.html) module"]
 pub struct SPI_TBR_SPEC;
 impl crate::RegisterSpec for SPI_TBR_SPEC {
     type Ux = u32;
